@@ -171,9 +171,21 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
         case TopMostParentSummary:
             return todo->summary();
         case TopMostParentDueDate: {
-            bool isOverdue = (todo->hasDueDate() && todo->dtDue().date() < QDate::currentDate() && todo->allDay())
-                || (todo->hasDueDate() && todo->dtDue() < QDateTime::currentDateTime() && !todo->allDay());
-            return isOverdue ? i18n("Overdue") : todo->hasDueDate() ? QLocale::system().toString(todo->dtDue().date()) : i18n("No set date");
+            if (!todo->hasDueDate()) {
+                return i18n("No set date");
+            }
+
+            const auto isOverdue =
+                (todo->allDay() && todo->dtDue().date() < QDate::currentDate()) || (!todo->allDay() && todo->dtDue() < QDateTime::currentDateTime());
+
+            if (isOverdue) {
+                return i18n("Overdue");
+            }
+
+            const auto dateInCurrentTZ = todo->dtDue().toLocalTime().date();
+            const auto isToday = dateInCurrentTZ == QDate::currentDate();
+
+            return isToday ? i18n("Today") : todo->dtDue().toString();
         }
         case TopMostParentPriority:
             return todo->priority();
@@ -473,11 +485,15 @@ int TodoSortFilterProxyModel::compareDueDates(const QModelIndex &left, const QMo
     } else if (!leftIsEmpty) { // Both have due dates
         const auto leftDateTime = leftTodo->dtDue();
         const auto rightDateTime = rightTodo->dtDue();
+        const auto leftOverdue = leftTodo->isOverdue();
+        const auto rightOverdue = rightTodo->isOverdue();
 
-        if (leftDateTime == rightDateTime) {
+        if (leftDateTime == rightDateTime && leftOverdue == rightOverdue) {
             return 0;
-        } else {
+        } else if (leftOverdue == rightOverdue) {
             return leftDateTime < rightDateTime ? -1 : 1;
+        } else {
+            return leftOverdue ? -1 : 1;
         }
     } else { // Neither has a due date
         return 0;
